infer_colgrps: Set Column Grouping for a Structured Data Frame
Description
Takes a data frame where each non row index is a data frame column, and
sets the corresponding column grouping.
Usage
infer_colgrps(x, index_name = "group", sep = "_")
Arguments
- x
A tibble with data frame data columns
- index_name
A name for the new column index
- sep
A character used to join the data column and group names