Learn R Programming

groupr (version 0.1.2)

sep_colgrp: Separate Columns By a Character

Description

Creates a column index by interpreting each column name as a data column name and a group name separated by sep. Only columns that are not row indices are used. sep must occur exactly once in each column name.

Usage

sep_colgrp(x, sep, index_name = "group")

Value

A grouped tibble

Arguments

x

A tibble

sep

A character delimiting the two parts of the name

index_name

A name for the new column index