Learn R Programming

groupr (version 0.1.2)

ungroup.igrouped_df: Ungroup a Tibble With Inapplicable Groups

Description

Ungroup method for tibbles that have inapplicable groups.

Usage

# S3 method for igrouped_df
ungroup(x, ...)

Value

A tibble with no groups. The "groups" attribute will be set to contain one column, .rows, with a single value that lists all rows.

Arguments

x

An igrouped tibble (as created by group_by2)

...

Ignored. All variables are removed from the grouping.